slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSPowerGetNonlinear

Returns a flag indicating if the problem is nonlinear.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSPowerGetNonlinear(EPS eps,PetscBool *nonlinear)

Not Collective

### Input Parameter

| eps | - the eigenproblem solver context

### Output Parameter

| nonlinear | - the nonlinear flag

### See Also

EPSPowerSetUpdate(), EPSPowerSetNonlinear()

### Level

advanced

### Location

src/eps/impls/power/power.c

### Examples

src/eps/tutorials/ex34.c.html
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages